@@ -697,7 +697,7 @@ class TestUrlDispatcher(unittest.TestCase):
         route = PlainRoute('GET', lambda req: None, None, '/path')
         self.router.register_route(route)
         resource = route.resource
-        self.assertEqual((None, {'GET'}),
+        self.assertEqual((None, set()),
                          self.loop.run_until_complete(
                              resource.resolve('GET', '/another/path')))
 
@@ -874,3 +874,41 @@ class TestUrlDispatcher(unittest.TestCase):
         self.assertIsInstance(self.router.resources(), Sized)
         self.assertIsInstance(self.router.resources(), Iterable)
         self.assertIsInstance(self.router.resources(), Container)
+
+    def test_static_route_user_home(self):
+        here = pathlib.Path(aiohttp.__file__).parent
+        home = pathlib.Path(os.path.expanduser('~'))
+        if not str(here).startswith(str(home)):  # pragma: no cover
+            self.skipTest("aiohttp folder is not placed in user's HOME")
+        static_dir = '~/' + str(here.relative_to(home))
+        route = self.router.add_static('/st', static_dir)
+        self.assertEqual(here, route.get_info()['directory'])
+
+    def test_static_route_points_to_file(self):
+        here = pathlib.Path(aiohttp.__file__).parent / '__init__.py'
+        with self.assertRaises(ValueError):
+            self.router.add_static('/st', here)
+
+    def test_404_for_resource_adapter(self):
+        route = self.router.add_static('/st',
+                                       os.path.dirname(aiohttp.__file__))
+        resource = route.resource
+        ret = self.loop.run_until_complete(
+            resource.resolve('GET', '/unknown/path'))
+        self.assertEqual((None, set()), ret)
+
+    def test_405_for_resource_adapter(self):
+        route = self.router.add_static('/st',
+                                       os.path.dirname(aiohttp.__file__))
+        resource = route.resource
+        ret = self.loop.run_until_complete(
+            resource.resolve('POST', '/st/abc.py'))
+        self.assertEqual((None, {'GET'}), ret)
+
+    def test_check_allowed_method_for_found_resource(self):
+        handler = self.make_handler()
+        resource = self.router.add_resource('/')
+        resource.add_route('GET', handler)
+        ret = self.loop.run_until_complete(resource.resolve('GET', '/'))
+        self.assertIsNotNone(ret[0])
+        self.assertEqual({'GET'}, ret[1])
